/***
* SIGCPP.H - Header file that allows the use of signal() for the
* handling of floating point and other exceptions in both C and C++.
* However, it is recommended that longjmp() not be used in C++ programs.
*  - Do not #include <signal.h> or <setjmp.h>.
*  - Whenever you call signal(), you need to put the following cast on
*    its second parameter, your handler:
*       (void (__cdecl *)(int, ...))
*  - Be very careful to avoid memory leakage with longjmp()'s in C++,
*    which will occur if destructors and other deletes are jumped.
****/

#ifndef _INC_SIGCPP

#ifdef __cplusplus
extern "C" {
#endif


#ifndef _CRTIMP
#ifdef _DLL
#define _CRTIMP __declspec(dllimport)
#else
#define _CRTIMP
#endif /* ?CRTDLL */
#endif


#ifndef _SIG_ATOMIC_T_DEFINED
typedef int sig_atomic_t;
#define _SIG_ATOMIC_T_DEFINED
#endif

#define NSIG 23     /* maximum signal number + 1 */

/* signal types */

#define SIGINT		2	/* interrupt */
#define SIGILL		4	/* illegal instruction - invalid function image */
#define SIGFPE		8	/* floating point exception */
#define SIGSEGV 	11	/* segment violation */
#define SIGTERM 	15	/* Software termination signal from kill */
#define SIGBREAK	21	/* Ctrl-Break sequence */
#define SIGABRT 	22	/* abnormal termination triggered by abort call */


/* signal action codes */

#define SIG_DFL (void (__cdecl *)(int))0	   /* default signal action */
#define SIG_IGN (void (__cdecl *)(int))1	   /* ignore signal */
#define SIG_SGE (void (__cdecl *)(int))3	   /* signal gets error */
#define SIG_ACK (void (__cdecl *)(int))4	   /* acknowledge */


/* signal error value (returned by signal call on error) */

#define SIG_ERR (void (__cdecl *)(int))-1	   /* signal error value */

/* pointer to exception information pointers structure */

#ifdef	_MT
extern void * * __cdecl __pxcptinfoptrs(void);
#define _pxcptinfoptrs	(*__pxcptinfoptrs())
#else
extern void * _pxcptinfoptrs;
#endif

/* function prototypes */

_CRTIMP void (__cdecl * __cdecl signal(int, void (__cdecl *)(int, ...)))(int);
_CRTIMP int __cdecl raise(int);





//    Setjmp.h
//
/*
 * Definitions specific to particular setjmp implementations.
 */
#ifdef	_M_IX86

#define setjmp	_setjmp
#define _JBLEN	8

#endif


/* define the buffer type for holding the state information */

#ifndef _JMP_BUF_DEFINED
typedef  int  jmp_buf[_JBLEN];
#define _JMP_BUF_DEFINED
#endif


/* function prototypes */

int __cdecl _setjmp(jmp_buf);
_CRTIMP void __cdecl longjmp(jmp_buf, int);


#ifdef __cplusplus
}
#endif


#define _INC_SIGCPP
#endif  /* _INC_SIGCPP */
